@@ -26,20 +26,27 @@ from cubicweb.uilib import domid
 from cubicweb.web import component
 from cubicweb.web.views import tableview
 
-from cubes.vcreview.views import patch_states_rql
+from cubes.vcreview.views import final_patch_states_rql
 
 class AllActivePatches(view.StartupView):
     __regid__ = 'vcreview.allactivepatches'
     title = _('All active patches')
 
-    rql = ('Any P,PO,P,P,PB,PS,COUNT(TR),R GROUPBY R,P,PO,PB,PS '
-           'ORDERBY RT,PB,PO WHERE P originator PO, P branch PB, P in_state PS,'
-           'TR? wf_info_for P, P patch_repository R, R title RT, '
-           'PS name %s')
+    rql = ('Any P,PO,P,P,PB,PS,COUNT(TR),R '
+           'GROUPBY R,P,PO,PB,PS '
+           'ORDERBY RT,PB,PO '
+           'WHERE P patch_revision RE, '
+           '      RE author PO, '
+           '      RE branch PB, '
+           '      P in_state PS,'
+           '      TR? wf_info_for P, '
+           '      RE from_repository R, '
+           '      R title RT, '
+           '      NOT PS name %s')
 
     @cached
     def filter_box_context_info(self):
-        rset = self._cw.execute(self.rql % patch_states_rql(self._cw))
+        rset = self._cw.execute(self.rql % final_patch_states_rql(self._cw))
         return rset, 'vcreview.patches.table', domid(self.__regid__), False
 
     def call(self):
@@ -52,13 +59,26 @@ class UserWorkList(AllActivePatches):
     __regid__ = 'vcreview.patches.worklist'
     title = _('My review worklist')
 
-    rql = ('Any P,PO,P,P,PB,PS,COUNT(TR),R GROUPBY R,P,PO,PB,PS '
-           'ORDERBY RT,PB,PO WHERE P originator PO, P branch PB, P in_state PS,'
-           'TR? wf_info_for P, P patch_repository R, R title RT, U eid %(u)s, '
-           'EXISTS(PS name "pending-review" AND P patch_reviewer U) '
-           'OR EXISTS(PS name "reviewed" AND P patch_committer U) '
-           'OR (EXISTS(PS name IN ("reviewed", "deleted") AND NOT EXISTS(P patch_committer V) '
-           '    AND (EXISTS(R repository_committer U) OR EXISTS(U in_group G, G name "committers"))))')
+    rql = ('Any P,PO,P,P,PB,PS,COUNT(TR),R '
+           'GROUPBY R,P,PO,PB,PS '
+           'ORDERBY RT,PB,PO '
+           'WHERE U eid %(u)s, '
+           '      P in_state PS, '
+           '      P patch_revision RE, '
+           '      RE author PO, '
+           '      RE branch PB, '
+           '      RE from_repository R, '
+           '      TR? wf_info_for P, '
+           '      R title RT, '
+           # Patch is pending review  and CWUser is reviewer
+           '      EXISTS(PS name "pending-review" AND P patch_reviewer U) '
+           # Patch is reviewed  and CWUser is commiter
+           '      OR EXISTS(PS name "reviewed" AND P patch_committer U) '
+           # Patch is reviewed  and CWUser repository or global commiter 
+           '      OR (EXISTS(PS name "reviewed"'
+           '          AND NOT EXISTS(P patch_committer V) '
+           '          AND (EXISTS(R repository_committer U)'
+           '              OR EXISTS(U in_group G, G name "committers"))))')
 
     @cached
     def filter_box_context_info(self):
@@ -66,10 +86,10 @@ class UserWorkList(AllActivePatches):
         return rset, 'vcreview.patches.table', domid(self.__regid__), False
 
 
-
 class PatchesTable(tableview.TableView):
     __regid__ = 'vcreview.patches.table'
     # XXX selector
+
     def call(self, **kwargs):
         kwargs['paginate'] = True
         super(PatchesTable, self).call(cellvids={2: 'vcreview.patch.reviewers', 3: 'vcreview.patch.committers'},
@@ -105,7 +125,7 @@ class WorkListLink(component.CtxComponent):
     __select__ = (component.CtxComponent.__select__
                   & ~anonymous_user()
                   & rql_condition(
-                      'P in_state PS, P patch_repository R, '
+                      'P in_state PS, P patch_revision RE, RE from_repository R,'
                       'EXISTS(PS name "pending-review" AND P patch_reviewer U) '
                       'OR EXISTS(PS name IN ("reviewed", "deleted") AND (EXISTS(R repository_committer U) '
                       'OR EXISTS(U in_group G, G name "committers")))',
